# OpenBB Equity Extension

This extension provides equity market data tools for the OpenBB Platform.

Features of the Equity extension include:

- Access to various equity market data sources
- Sub-modules such as:
  - `calendar` for equity-specific events
  - `compare` for peer analysis
  - `darkpool` for dark pool shorts data
  - `discovery` for equity discovery
  - `estimates` for analyst estimates
  - `fundamental` for fundamental analysis
  - `options` for options
  - `ownership` for internal and external ownership
  - `price` for historical pricing data
  - `shorts` for shorts data

## Installation

To install the extension, run the following command in this folder:

```bash
pip install openbb-equity
```

Documentation available [here](https://docs.openbb.co/platform/developer_guide/contributing).
